gc3libs.persistence.serialization — gc3pie development (SVN $Revision$) documentation

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- Programmer Documentation »
- GC3Libs programming API »

# gc3libs.persistence.serialization

Generic object serialization (using Python’s pickle/cPickle modules).

See the documentation for Python’s standard *pickle* and *cPickle* modules for more details.

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- Programmer Documentation »
- GC3Libs programming API »